import {basicTransition, elevation, makeMedia} from "rms-meteor-styles";
import type {MeteorDialogStyleConfig} from "./types.js";
import {coverScreen, flexCentered, rgba, fontWeight} from "rms-meteor-styles/js/mixins";

const {mobile} = makeMedia();
const DEFAULT_STYLE_CONFIG: MeteorDialogStyleConfig = {
  brandColor: "#FF0000",
  fontWeight
};

export const makeMeteorDialogStyles = (config: ?MeteorDialogStyleConfig) => {
  const {brandColor, fontWeight} = {...DEFAULT_STYLE_CONFIG, ...config};
  return (
    {
      wrapper: {
        ...coverScreen(),
        ...flexCentered(),
        background: rgba('#000000', .3),
        ...basicTransition('opacity', 'visibility'),
        visibility: 'hidden',
        opacity: 0,
        zIndex: -1,

      },

      active: {
        wrapper: {
          visibility: 'visible',
          zIndex: 6,
          opacity: 1
        }
      },

      dialog: {
        background: 'white',
        ...elevation(5),
        maxWidth: '50%',
        minWidth: 250,
        maxHeight: '96vh',
        overflowY: 'hidden',
        overflowX: 'hidden',
        ...mobile({
          maxWidth: '80%',
          minWidth: 100,
          maxHeight: '90vh',
        })
      },

      loading: {
        dialogContent: {
          display: 'flex',
          flexDirection: 'column',
          alignItems: 'center',
        },
        dialogTitle: {
          marginBottom: 6
        },
        loader: {
          width: 120
        }
      },

      dialogContent: {
        paddingTop: 8,
        paddingLeft: 24,
        paddingRight: 24,
        paddingBottom: 24
      },

      dialogTitle: {
        ...fontWeight('bold'),
        textTransform: 'capitalize'
      },

      dialogMessage: {
        marginTop: 20
      },


      dialogActionWrapper: {
        width: '100%',
        display: 'flex',
        justifyContent: 'flex-end',
        alignItems: 'center',
      },

      dialogAction: {
        marginRight: 8,
        marginTop: 8,
        marginBottom: 8,
        ...flexCentered(),
        height: 36,
        position: 'relative',
        padding: 8,
        cursor: 'pointer'
      },
      dialogActionTitle: {
        textTransform: 'uppercase',
        positive: {
          ...fontWeight('bold'),
          textTransform: 'uppercase',
          color: brandColor
        },
        negative: {

        }
      },

      kinds: {
        product: {
          dialog: {
            maxWidth: '83%',
            ...mobile({
              maxWidth: '90%',
            })
          },
          dialogTitle: {
            ...mobile({
              textAlign: 'center'
            })
          },
          dialogMessage: {
            ...mobile({
              textAlign: 'center'
            })
          },

        }
      }
    }
  );
};